@@ -1,7 +1,7 @@
 import requests
-from settings import *
-from helper_baza_gai import *
-from dto import CarEntity
+from .settings import *
+from .helper_baza_gai import *
+from .dto import CarEntity
 
 
 def search_gai_base_car_number(car_number: str):
